@@ -360,7 +360,7 @@ def _generate_interface(
 
     # endregion
 
-    # region Methods
+    # region Signatures
 
     for signature in interface.signatures:
         signature_blocks = []  # type: List[Stripped]
@@ -883,8 +883,15 @@ def _generate_class(
 
     for method in cls.methods:
         if isinstance(method, intermediate.ImplementationSpecificMethod):
+            # NOTE (mristin, 2022-05-18):
+            # We have to repeat the implementation of the method in all the descendants
+            # since we share only interfaces between the classes, but not
+            # the implementations.
+            #
+            # This makes the code a bit larger, but the class hierarchy is much simpler
+            # and the individual classes are much easier to grasp.
             implementation_key = specific_implementations.ImplementationKey(
-                f"{cls.name}/{method.name}.cs"
+                f"Types/{method.specified_for.name}/{method.name}.cs"
             )
 
             implementation = spec_impls.get(implementation_key, None)
@@ -921,66 +928,58 @@ def _generate_class(
 
     blocks.append(
         Stripped(
-            textwrap.dedent(
-                f"""\
-        /// <summary>
-        /// Accept the <paramref name="visitor" /> to visit this instance
-        /// for double dispatch.
-        /// </summary>
-        public void Accept(Visitation.IVisitor visitor)
-        {{
-        {I}visitor.Visit(this);
-        }}"""
-            )
+            f"""\
+/// <summary>
+/// Accept the <paramref name="visitor" /> to visit this instance
+/// for double dispatch.
+/// </summary>
+public void Accept(Visitation.IVisitor visitor)
+{{
+{I}visitor.Visit(this);
+}}"""
         )
     )
 
     blocks.append(
         Stripped(
-            textwrap.dedent(
-                f"""\
-        /// <summary>
-        /// Accept the visitor to visit this instance for double dispatch
-        /// with the <paramref name="context" />.
-        /// </summary>
-        public void Accept<C>(Visitation.IVisitorWithContext<C> visitor, C context)
-        {{
-        {I}visitor.Visit(this, context);
-        }}"""
-            )
+            f"""\
+/// <summary>
+/// Accept the visitor to visit this instance for double dispatch
+/// with the <paramref name="context" />.
+/// </summary>
+public void Accept<C>(Visitation.IVisitorWithContext<C> visitor, C context)
+{{
+{I}visitor.Visit(this, context);
+}}"""
         )
     )
 
     blocks.append(
         Stripped(
-            textwrap.dedent(
-                f"""\
-        /// <summary>
-        /// Accept the <paramref name="transformer" /> to transform this instance
-        /// for double dispatch.
-        /// </summary>
-        public T Transform<T>(Visitation.ITransformer<T> transformer)
-        {{
-        {I}return transformer.Transform(this);
-        }}"""
-            )
+            f"""\
+/// <summary>
+/// Accept the <paramref name="transformer" /> to transform this instance
+/// for double dispatch.
+/// </summary>
+public T Transform<T>(Visitation.ITransformer<T> transformer)
+{{
+{I}return transformer.Transform(this);
+}}"""
         )
     )
 
     blocks.append(
         Stripped(
-            textwrap.dedent(
-                f"""\
-        /// <summary>
-        /// Accept the <paramref name="transformer" /> to visit this instance
-        /// for double dispatch with the <paramref name="context" />.
-        /// </summary>
-        public T Transform<C, T>(
-        {I}Visitation.ITransformerWithContext<C, T> transformer, C context)
-        {{
-        {I}return transformer.Transform(this, context);
-        }}"""
-            )
+            f"""\
+/// <summary>
+/// Accept the <paramref name="transformer" /> to visit this instance
+/// for double dispatch with the <paramref name="context" />.
+/// </summary>
+public T Transform<C, T>(
+{I}Visitation.ITransformerWithContext<C, T> transformer, C context)
+{{
+{I}return transformer.Transform(this, context);
+}}"""
         )
     )
 
@@ -990,7 +989,7 @@ def _generate_class(
 
     if cls.constructor.is_implementation_specific:
         implementation_key = specific_implementations.ImplementationKey(
-            f"{cls.name}/{cls.name}.cs"
+            f"Types/{cls.name}/{cls.name}.cs"
         )
         implementation = spec_impls.get(implementation_key, None)
 
@@ -1066,50 +1065,48 @@ def generate(
     blocks.append(
         Rstripped(
             textwrap.indent(
-                textwrap.dedent(
-                    f"""\
-        /// <summary>
-        /// Represent a general class of an AAS model.
-        /// </summary>
-        public interface IClass
-        {{
-            /// <summary>
-            /// Iterate over all the class instances referenced from this instance
-            /// without further recursion.
-            /// </summary>
-            public IEnumerable<IClass> DescendOnce();
+                f"""\
+/// <summary>
+/// Represent a general class of an AAS model.
+/// </summary>
+public interface IClass
+{{
+{I}/// <summary>
+{I}/// Iterate over all the class instances referenced from this instance
+{I}/// without further recursion.
+{I}/// </summary>
+{I}public IEnumerable<IClass> DescendOnce();
 
-            /// <summary>
-            /// Iterate recursively over all the class instances referenced from this instance.
-            /// </summary>
-            public IEnumerable<IClass> Descend();
+{I}/// <summary>
+{I}/// Iterate recursively over all the class instances referenced from this instance.
+{I}/// </summary>
+{I}public IEnumerable<IClass> Descend();
 
-            /// <summary>
-            /// Accept the <paramref name="visitor" /> to visit this instance
-            /// for double dispatch.
-            /// </summary>
-            public void Accept(Visitation.IVisitor visitor);
+{I}/// <summary>
+{I}/// Accept the <paramref name="visitor" /> to visit this instance
+{I}/// for double dispatch.
+{I}/// </summary>
+{I}public void Accept(Visitation.IVisitor visitor);
 
-            /// <summary>
-            /// Accept the visitor to visit this instance for double dispatch
-            /// with the <paramref name="context" />.
-            /// </summary>
-            public void Accept<C>(Visitation.IVisitorWithContext<C> visitor, C context);
+{I}/// <summary>
+{I}/// Accept the visitor to visit this instance for double dispatch
+{I}/// with the <paramref name="context" />.
+{I}/// </summary>
+{I}public void Accept<C>(Visitation.IVisitorWithContext<C> visitor, C context);
 
-            /// <summary>
-            /// Accept the <paramref name="transformer" /> to transform this instance
-            /// for double dispatch.
-            /// </summary>
-            public T Transform<T>(Visitation.ITransformer<T> transformer);
+{I}/// <summary>
+{I}/// Accept the <paramref name="transformer" /> to transform this instance
+{I}/// for double dispatch.
+{I}/// </summary>
+{I}public T Transform<T>(Visitation.ITransformer<T> transformer);
 
-            /// <summary>
-            /// Accept the <paramref name="transformer" /> to visit this instance
-            /// for double dispatch with the <paramref name="context" />.
-            /// </summary>
-            public T Transform<C, T>(
-            {I}Visitation.ITransformerWithContext<C, T> transformer, C context);
-        }}"""
-                ),
+{I}/// <summary>
+{I}/// Accept the <paramref name="transformer" /> to visit this instance
+{I}/// for double dispatch with the <paramref name="context" />.
+{I}/// </summary>
+{I}public T Transform<C, T>(
+{II}Visitation.ITransformerWithContext<C, T> transformer, C context);
+}}""",
                 I,
             )
         )
@@ -1128,7 +1125,7 @@ def generate(
             and something.is_implementation_specific
         ):
             implementation_key = specific_implementations.ImplementationKey(
-                f"{something.name}.cs"
+                f"Types/{something.name}.cs"
             )
 
             code = spec_impls.get(implementation_key, None)
