@@ -22,6 +22,8 @@ Stringifiable = Union[
     PrimitiveStringifiable,
     Sequence[PrimitiveStringifiable],
     Sequence[Sequence[PrimitiveStringifiable]],
+    Mapping[str, PrimitiveStringifiable],
+    Mapping[str, Sequence[PrimitiveStringifiable]],
 ]
 
 
@@ -71,9 +73,22 @@ class Entity:
 
 def dump(stringifiable: Stringifiable) -> str:
     """Produce a string representation of ``stringifiable`` for debugging or testing."""
-    if isinstance(stringifiable, (bool, int, float, str)):
+    if isinstance(stringifiable, (bool, int, float)):
         return repr(stringifiable)
 
+    elif isinstance(stringifiable, str):
+        if "\n" not in stringifiable or "\r" in stringifiable or '"""' in stringifiable:
+            return repr(stringifiable)
+
+        # NOTE (mristin, 2022-05-18):
+        # A multi-line string literal is much more readable when it comes to diffing.
+
+        escaped = stringifiable.replace("\\", "\\\\")
+
+        indented = "\n".join(f"  {line}" for line in escaped.splitlines())
+
+        return f'textwrap.dedent("""\\\n{indented}""")'
+
     elif isinstance(stringifiable, Entity):
         if len(stringifiable.properties) == 0:
             return f"{stringifiable.name}()"
@@ -118,6 +133,25 @@ def dump(stringifiable: Stringifiable) -> str:
 
             return writer.getvalue()
 
+    elif isinstance(stringifiable, collections.abc.Mapping):
+        if len(stringifiable) == 0:
+            return "{}"
+        else:
+            writer = io.StringIO()
+            writer.write("{\n")
+            for i, (key, value) in enumerate(stringifiable.items()):
+                key_str = dump(key)
+
+                value_str = dump(value)
+                writer.write(textwrap.indent(f"{key_str}: {value_str}", "  "))
+
+                if i == len(stringifiable) - 1:
+                    writer.write("}")
+                else:
+                    writer.write(",\n")
+
+            return writer.getvalue()
+
     elif stringifiable is None:
         return repr(None)
 
