@@ -102,10 +102,7 @@ class Test_against_recorded(unittest.TestCase):
                     pathlib.Path("reporting.cs"),
                     pathlib.Path("stringification.cs"),
                     pathlib.Path("jsonization.cs"),
-                    # BEFORE-RELEASE (mristin, 2021-12-19):
-                    #  Uncomment and make sure it is implemented once we nailed down
-                    #  how the XML de/serialization should be implemented.
-                    # pathlib.Path('xmlization.cs')
+                    pathlib.Path("xmlization.cs"),
                 ]:
                     expected_pth = expected_output_dir / relevant_rel_pth
                     output_pth = output_dir / relevant_rel_pth
